# anime-dl

A simple command line tool written in python to download anime.

## Installation

```sh
$ pip install anime-dl
```

## Usage

```
usage: anime-dl [-h] [-v] -s KEYWORD

A simple command-line tool to download anime.

optional arguments:
  -h, --help                    show this help message and exit
  -v, --version                 display the version and exit
  -s KEYWORD, --search KEYWORD  search for an anime
```

## License

Distributed under the MIT License. See [LICENSE](LICENSE)  for more information.

[![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)](https://forthebadge.com)